@@ -170,9 +170,8 @@ func TestCodeHighlighting(t *testing.T) {
 	}
 
 	reader, err := NewReaderFromFilename(filename, *styles.Get("native"), formatters.TTY16m, nil)
-	if err != nil {
-		panic(err)
-	}
+	assert.NilError(t, err)
+	assert.NilError(t, reader._wait())
 
 	packageKeywordStyle := twin.StyleDefault.WithAttr(twin.AttrBold).WithForeground(twin.NewColorHex(0x6AB825))
 	packageNameStyle := twin.StyleDefault.WithForeground(twin.NewColorHex(0xD0D0D0))
@@ -219,15 +218,9 @@ func testManPageFormatting(t *testing.T, input string, expected twin.Cell) {
 
 	// Without these lines the man page tests will fail if either of these
 	// environment variables are set when the tests are run.
-	if err := os.Setenv("LESS_TERMCAP_md", ""); err != nil {
-		panic(err)
-	}
-	if err := os.Setenv("LESS_TERMCAP_us", ""); err != nil {
-		panic(err)
-	}
-	if err := os.Setenv("LESS_TERMCAP_so", ""); err != nil {
-		panic(err)
-	}
+	assert.NilError(t, os.Setenv("LESS_TERMCAP_md", ""))
+	assert.NilError(t, os.Setenv("LESS_TERMCAP_us", ""))
+	assert.NilError(t, os.Setenv("LESS_TERMCAP_so", ""))
 	resetManPageFormat()
 
 	contents := startPaging(t, reader).GetRow(0)
@@ -236,9 +229,12 @@ func testManPageFormatting(t *testing.T, input string, expected twin.Cell) {
 }
 
 func TestManPageFormatting(t *testing.T) {
-	testManPageFormatting(t, "N\x08N", twin.NewCell('N', twin.StyleDefault.WithAttr(twin.AttrBold)))
+	testManPageFormatting(t, "n\x08n", twin.NewCell('n', twin.StyleDefault.WithAttr(twin.AttrBold)))
 	testManPageFormatting(t, "_\x08x", twin.NewCell('x', twin.StyleDefault.WithAttr(twin.AttrUnderline)))
 
+	// Non-breaking space UTF-8 encoded (0xc2a0) should render as a non-breaking unicode space (0xa0)
+	testManPageFormatting(t, string([]byte{0xc2, 0xa0}), twin.NewCell(rune(0xa0), twin.StyleDefault))
+
 	// Corner cases
 	testManPageFormatting(t, "\x08", twin.NewCell('<', twin.StyleDefault.WithForeground(twin.NewColor16(7)).WithBackground(twin.NewColor16(1))))
 
@@ -272,13 +268,11 @@ func TestFindFirstHitSimple(t *testing.T) {
 	pager := NewPager(reader)
 	pager.screen = twin.NewFakeScreen(40, 10)
 
-	// Wait for reader to finish reading
-	for !reader.done.Load() {
-	}
+	assert.NilError(t, pager.reader._wait())
 
 	pager.searchPattern = toPattern("AB")
 
-	hit := pager.findFirstHit(newScrollPosition("TestFindFirstHitSimple"), false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
 	assert.Assert(t, hit.internalDontTouch.lineNumber.IsZero())
 	assert.Equal(t, hit.internalDontTouch.deltaScreenLines, 0)
 }
@@ -288,13 +282,11 @@ func TestFindFirstHitAnsi(t *testing.T) {
 	pager := NewPager(reader)
 	pager.screen = twin.NewFakeScreen(40, 10)
 
-	// Wait for reader to finish reading
-	for !reader.done.Load() {
-	}
+	assert.NilError(t, pager.reader._wait())
 
 	pager.searchPattern = toPattern("AB")
 
-	hit := pager.findFirstHit(newScrollPosition("TestFindFirstHitSimple"), false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
 	assert.Assert(t, hit.internalDontTouch.lineNumber.IsZero())
 	assert.Equal(t, hit.internalDontTouch.deltaScreenLines, 0)
 }
@@ -304,13 +296,25 @@ func TestFindFirstHitNoMatch(t *testing.T) {
 	pager := NewPager(reader)
 	pager.screen = twin.NewFakeScreen(40, 10)
 
-	// Wait for reader to finish reading
-	for !reader.done.Load() {
-	}
+	assert.NilError(t, pager.reader._wait())
 
 	pager.searchPattern = toPattern("this pattern should not be found")
 
-	hit := pager.findFirstHit(newScrollPosition("TestFindFirstHitSimple"), false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
+	assert.Assert(t, hit == nil)
+}
+
+func TestFindFirstHitNoMatchBackwards(t *testing.T) {
+	reader := NewReaderFromText("TestFindFirstHitSimple", "AB")
+	pager := NewPager(reader)
+	pager.screen = twin.NewFakeScreen(40, 10)
+
+	assert.NilError(t, pager.reader._wait())
+
+	pager.searchPattern = toPattern("this pattern should not be found")
+	theEnd := *linenumbers.LineNumberFromLength(reader.GetLineCount())
+
+	hit := pager.findFirstHit(theEnd, true)
 	assert.Assert(t, hit == nil)
 }
 
@@ -336,9 +340,7 @@ func TestScrollToBottomWrapNextToLastLine(t *testing.T) {
 	pager.ShowLineNumbers = false
 	pager.screen = screen
 
-	// Wait for reader to finish reading
-	for !reader.done.Load() {
-	}
+	assert.NilError(t, pager.reader._wait())
 
 	// This is what we're testing really
 	pager.scrollToEnd()
@@ -486,7 +488,7 @@ func TestIsScrolledToEnd_EmptyFile(t *testing.T) {
 
 // Verify that we can page all files in ../sample-files/* without crashing
 func TestPageSamples(t *testing.T) {
-	for _, fileName := range getTestFiles() {
+	for _, fileName := range getTestFiles(t) {
 		t.Run(fileName, func(t *testing.T) {
 			file, err := os.Open(fileName)
 			if err != nil {
@@ -500,8 +502,7 @@ func TestPageSamples(t *testing.T) {
 			}()
 
 			myReader := NewReaderFromStream(fileName, file, chroma.Style{}, nil, nil)
-			for !myReader.done.Load() {
-			}
+			assert.NilError(t, myReader._wait())
 
 			pager := NewPager(myReader)
 			pager.WrapLongLines = false
@@ -622,17 +623,13 @@ func benchmarkSearch(b *testing.B, highlighted bool) {
 	}
 
 	sourceBytes, err := os.ReadFile(sourceFilename)
-	if err != nil {
-		panic(err)
-	}
+	assert.NilError(b, err)
 	fileContents := string(sourceBytes)
 
 	// Read one copy of the example input
 	if highlighted {
 		highlightedSourceCode, err := highlight(fileContents, *styles.Get("native"), formatters.TTY16m, lexers.Get("go"))
-		if err != nil {
-			panic(err)
-		}
+		assert.NilError(b, err)
 		if highlightedSourceCode == nil {
 			panic("Highlighting didn't want to, returned nil")
 		}
@@ -659,7 +656,7 @@ func benchmarkSearch(b *testing.B, highlighted bool) {
 	b.ResetTimer()
 
 	// This test will search through all the N copies we made of our file
-	hit := pager.findFirstHit(newScrollPosition("benchmarkSearch"), false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
 
 	if hit != nil {
 		panic(fmt.Errorf("This test is meant to scan the whole file without finding anything"))
