@@ -57,6 +57,14 @@ type Screen interface {
 	// If the position is outside of the screen, the cursor will be hidden.
 	ShowCursorAt(column int, row int)
 
+	// RequestTerminalBackgroundColor() asks the terminal to report its
+	// background color.
+	//
+	// If your terminal supports background color queries and it responds, the
+	// result will be reported as an EventTerminalBackgroundDetected on the
+	// Events() channel.
+	RequestTerminalBackgroundColor()
+
 	// This channel is what your main loop should be checking.
 	Events() chan Event
 }
@@ -140,13 +148,6 @@ func NewScreenWithMouseModeAndColorType(mouseMode MouseMode, terminalColorCount
 		return nil, fmt.Errorf("problem setting up TTY: %w", err)
 	}
 
-	// Request to get terminal background color. Answer will be handled in our
-	// main loop.
-	//
-	// Ref:
-	// https://stackoverflow.com/questions/2507337/how-to-determine-a-terminals-background-color
-	fmt.Println("\x1b]11;?\x07")
-
 	screen.setAlternateScreenMode(true)
 
 	if mouseMode == MouseModeAuto {
@@ -524,6 +525,12 @@ func (screen *UnixScreen) Size() (width int, height int) {
 	return screen.widthAccessFromSizeOnly, screen.heightAccessFromSizeOnly
 }
 
+func (screen *UnixScreen) RequestTerminalBackgroundColor() {
+	// Ref:
+	// https://stackoverflow.com/questions/2507337/how-to-determine-a-terminals-background-color
+	fmt.Println("\x1b]11;?\x07")
+}
+
 func parseTerminalBgColorResponse(responseBytes []byte) *Color {
 	prefix := "\x1b]11;rgb:"
 	suffix1 := "\x07"
